@@ -1,6 +1,18 @@
-# SPDX-FileCopyrightText: 2020 Splunk Inc.
 #
-# SPDX-License-Identifier: Apache-2.0
+# Copyright 2021 Splunk Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
 
 """
 Copyright (C) 2005-2019 Splunk Inc. All Rights Reserved.
@@ -94,13 +106,6 @@ def extract_datainput_name(stanza_name):
     return stanza_name[idx + len(sep) :]
 
 
-def escape_json_control_chars(json_str):
-    control_chars = ((r"\n", "\\\\n"), (r"\r", "\\\\r"), (r"\r\n", "\\\\r\\\\n"))
-    for ch, replace in control_chars:
-        json_str = json_str.replace(ch, replace)
-    return json_str
-
-
 def disable_stdout_buffer():
     os.environ["PYTHONUNBUFFERED"] = "1"
     sys.stdout = os.fdopen(sys.stdout.fileno(), "wb", 0)
